#
# spec file for package perf
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# perf does not link with LTO
%define _lto_cflags %{nil}
%define version %(rpm -q --qf '%%{VERSION}' kernel-source)
%define version_pure %(echo %{version}|sed 's@\\([0-9]*\\)\\.\\([0-9]*\\).*@\\1\\2@')
%ifarch s390x s390
%define         _perf_unwind NO_LIBUNWIND=1
%else
%define         _perf_unwind %{nil}
BuildRequires:  libunwind-devel
%endif
%{?sle15_python_module_pythons}
Name:           perf
Version:        %{version}
Release:        92.25
Summary:        Performance Monitoring Tools for Linux
License:        GPL-2.0-only
Group:          Development/Tools/Debuggers
URL:            https://perf.wiki.kernel.org/
BuildRequires:  OpenCSD-devel
BuildRequires:  audit-devel
%ifnarch %{arm}
BuildRequires:  babeltrace-devel
%endif
BuildRequires:  binutils-devel
BuildRequires:  bison
BuildRequires:  clang
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  gtk2-devel
BuildRequires:  kernel-source >= 2.6.31
BuildRequires:  libcap-devel
# Debuginfod integration has major issues: boo#1213785
#BuildRequires:  libdebuginfod-devel
BuildRequires:  libdw-devel
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  libelf-devel
BuildRequires:  libtraceevent-devel
BuildRequires:  libzstd-devel
BuildRequires:  llvm
BuildRequires:  newt-devel
BuildRequires:  openssl-devel
BuildRequires:  python-rpm-macros
BuildRequires:  xz-devel
BuildRequires:  zlib-devel
BuildRequires:  rubygem(asciidoctor)
%ifarch aarch64 ia64 x86_64 ppc64 ppc64le ppc %sparc
BuildRequires:  libnuma-devel
%endif
Recommends:     kernel >= 2.6.31
Recommends:     perf-gtk
%{perl_requires}
%{?libperl_requires}

# Add local patches below here based on {version_pure}:
#
# Example: for kernel version 6.14.* {version_pure} = 614 and local patches on
# top of this (that will be in 6.15) should be numbered 6140-6149. Unlike SLE
# we only carry a handful of local patches in Factory.
#
# This avoids the perf build breaking when the kernel version in Factory
# asynchronously updates.

%define python_subpackage_only 1
%python_subpackages

%description
This package provides a userspace tool 'perf', which monitors performance for
either unmodified binaries or the entire system. It requires a Linux kernel
which includes the Performance Counters for Linux (PCL) subsystem (>= 2.6.31).
This subsystem utilizes the Performance Monitoring Unit (PMU) / hardware
counters of the underlying cpu architecture (if supported).

%package gtk
Summary:        Gtk browser for perf-report
Group:          Development/Tools/Other
Requires:       %{name} = %{version}

%description gtk
A GTK2 frontend for perf-report. (Use `perf report --gtk`.)

%package devel
Summary:        Development headers for perf
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}

%description devel
Development headers for perf. This is currently only dlfilter header.

%package bash-completion
Summary:        Bash completion for perf
Group:          System/Shells
Requires:       %{name}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)

%description bash-completion
bash command line completion support for perf.

%package rebuild
Summary:        Empty package to ensure rebuilding perf in OBS
%requires_eq kernel-source

%description rebuild
This is an empty package that ensures perf is rebuilt every time
kernel-default is rebuilt in OBS.

There is no reason to install this package.

%package -n python-perf
Summary:        Python Bindings for Manipulating Perf Events
Group:          Development/Languages/Python
Requires:       %{name} = %{version}

%description -n python-perf
This package contains a module that permits applications written in
the Python programming language to manipulate perf events.

%prep
# copy necessary files from kernel-source since we need to modify them
(cd %{_prefix}/src/linux ; tar -cf - COPYING CREDITS README tools include scripts Kbuild Makefile arch/*/{include,lib,tools,Makefile} lib kernel/bpf/disasm.[ch]) | tar -xf -
chmod +x tools/perf/util/generate-cmdlist.sh
%autopatch -p1 -m%{version_pure}0

# don't error out on deprecated definitions in gtk2.h
sed -i 's@ignored "-Wstrict-prototypes"@&\n#pragma GCC diagnostic ignored "-Wdeprecated-declarations"@' tools/build/feature/test-gtk2.c

# skip info-from-txt generation (it's the same as man anyway)
sed -i.old 's@\(all: .*\)info@\1@' tools/perf/Documentation/Makefile

# PASS rpm optflags as EXTRA_FLAGS, passing as CFLAGS overrides and breaks build
%define perf_options LIBTRACEEVENT_DYNAMIC=1 BUILD_BPF_SKEL=1 EXTRA_CFLAGS="%{optflags}" ASCIIDOC8=1 USE_ASCIIDOCTOR=1 CORESIGHT=1 GTK2=1 prefix=%{_prefix} libdir=%{_libdir} perfexecdir=lib/%{name}-core tipdir=share/doc/packages/perf %{_perf_unwind}

%build
cd tools/perf
export WERROR=0

# Specifying "all doc" as one invocation when using -f Makefile.perf doesn't
# work and all compiling is deferred to later %install; so seperate into two
make %{?_smp_mflags} -f Makefile.perf \
	V=0 VF=0 \
	%{perf_options} \
	all

make %{?_smp_mflags} -f Makefile.perf \
	V=0 VF=0 \
	%{perf_options} \
	doc

%install
cd tools/perf
export WERROR=0
make -f Makefile.perf \
	%{perf_options} \
	DESTDIR=%{buildroot} \
	install install-doc

# Install all python-perf flavors
%{python_expand #
rm -rf python_ext_build/*
make -f Makefile.perf \
	PYTHON=$python \
	%{perf_options} \
	DESTDIR=%{buildroot} \
	install-python_ext
}

mkdir -p %{buildroot}%{_datadir}/bash-completion/completions/
mv %{buildroot}%{_sysconfdir}/bash_completion.d/perf %{buildroot}%{_datadir}/bash-completion/completions/

# temp workaround as perf Makefile is still installing plugins even with LIBTRACEEVENT_DYNAMIC=1
rm -rf %{buildroot}/%{_libdir}/traceevent

%fdupes %{buildroot}/%{_prefix}/lib/%{name}-core

%files
%license COPYING
%doc CREDITS README tools/perf/design.txt
%if 0%{?suse_version} > 1315
%attr(0644, root, root) %doc %{_docdir}/perf/tips.txt
%endif
%{_bindir}/perf
%{_bindir}/trace
%{_prefix}/lib/%{name}-core
%{_mandir}/man1/perf*

%files gtk
%{_libdir}/libperf-gtk.so

%files bash-completion
%dir %{_datadir}/bash-completion
%dir %{_datadir}/bash-completion/completions
%{_datadir}/bash-completion/completions/perf

%files devel
%dir %{_includedir}/perf/
%{_includedir}/perf/*.h

%files rebuild
%license COPYING

%files %{python_files perf}
%defattr(-,root,root)
%{python_sitearch}/perf*

%changelog
* Thu Apr 17 2025 Dominique Leuenberger <dimstar@opensuse.org>
- Drop perf-tools-annotate-asm_pure_loop.S.patch: 6.14.2, which is
  in Factory, contains this patch already (boo#1241339).
* Wed Apr  9 2025 Jiri Slaby <jslaby@suse.cz>
- drop conditional perf-core (see below), 6.14 hit factory already
* Tue Apr  8 2025 Tony Jones <tonyj@suse.com>
- perf tools: annotate asm_pure_loop.S (bsc#1239906).
  New patch: perf-tools-annotate-asm_pure_loop.S.patch
- Add a brief explanation in spec on patch numbering convention.
* Mon Feb 10 2025 Jiri Slaby <jslaby@suse.cz>
- drop perf_tools_Build_x86_32-bit_syscall_table_from_arch_x86_entry_syscalls_syscall_32.tbl.patch
  6.12 is in factory for a long time.
- support 6.14: /usr/share/perf-core no longer installed after
  libaudit support dropped in 3cc550f5bbcf
* Thu Nov 14 2024 Jiri Slaby <jslaby@suse.cz>
- drop perf-fix-non-listed-archs.patch
  it was merged to 6.11.7
* Wed Oct 23 2024 Jiri Slaby <jslaby@suse.cz>
- use %%{version_pure} for patch in/exclusion (and apply 6.12 patch only
  on < 6.12)
* Thu Oct 10 2024 Jiri Slaby <jslaby@suse.cz>
- add perf-fix-non-listed-archs.patch to fix armv7l build
* Mon Sep  2 2024 Jiri Slaby <jslaby@suse.cz>
- Replace 0001-perf-trace-fix-build-on-32bit.patch by a proposed fix:
  perf_tools_Build_x86_32-bit_syscall_table_from_arch_x86_entry_syscalls_syscall_32.tbl.patch
* Fri Aug 30 2024 Jiri Slaby <jslaby@suse.cz>
- add 0001-perf-trace-fix-build-on-32bit.patch
  to fix build on i586 with 6.11+
* Tue Feb 27 2024 Tony Jones <tonyj@suse.com>
- Fix issue where target=all was not building until %%install
- Abstract out common make options to avoid specifying every time.
* Tue Feb 27 2024 Tony Jones <tonyj@suse.com>
- Improve summary/description for python-perf package.
  Add dependecy on perf version.
* Tue Feb 27 2024 Daniel Garcia <daniel.garcia@suse.com>
- Build python-perf packages for all python flavors
* Tue Jan  9 2024 Jiri Slaby <jslaby@suse.cz>
- remove 6.5 code
- fix build with 6.7 (tar also arch/*/tools)
* Mon Sep 18 2023 Jiri Slaby <jslaby@suse.cz>
- fix build for 6.6
* Wed Aug 16 2023 Fabian Vogt <fvogt@suse.com>
- Disable debuginfod integration (boo#1213785)
* Thu May 11 2023 Jiri Slaby <jslaby@suse.cz>
- add gcc and gcc-c++ to BuildRequires. gcc is needed but not
  listed. c++ is not installed by default and is needed since 6.4.
* Wed Jan 11 2023 Jiri Slaby <jslaby@suse.cz>
- fix build for 6.2
* Mon Jan  9 2023 Jiri Slaby <jslaby@suse.cz>
- drop perf-6.0-lock_contention_fix_a_build_error_on_32_bit.patch
  (6.1 landed to TW)
* Wed Oct 12 2022 Jiri Slaby <jslaby@suse.cz>
- drop perf-5.15-don-t-install-headers-with-x-permissions.patch
  (6.0 landed to TW)
* Fri Oct  7 2022 Callum Farmer <gmbr3@opensuse.org>
- Move bash-completion to subpackage so it isn't installed when
  not needed
* Thu Oct  6 2022 Andreas Schwab <schwab@suse.de>
- Add a dummy -rebuild package to give OBS/Tumbleweed a hint when this
  package needs a rebuild
* Mon Oct  3 2022 Jiri Slaby <jslaby@suse.cz>
- add perf-6.0-lock_contention_fix_a_build_error_on_32_bit.patch
  * needed still in 6.0 to fix build on 32bit.
* Mon Sep 12 2022 Jiri Slaby <jslaby@suse.cz>
- remove perf-6.0-don-t-install-headers-with-x-permissions.patch
  It is a part of 6.0-rc5, finally!
* Wed Sep  7 2022 Jiri Slaby <jslaby@suse.cz>
- Fix for kernel 6.0
  * add perf-6.0-don-t-install-headers-with-x-permissions.patch
  * add python3-setuptools to BuildRequires
* Wed Apr 20 2022 Martin Liška <mliska@suse.cz>
- Enable debuginfod support.
* Fri Mar 25 2022 Tony Jones <tonyj@suse.com>
- Enable bpf skel support.
  This enables shared counter support (--bpf-counters in perf-stat)
* Thu Feb 24 2022 Jiri Slaby <jslaby@suse.cz>
- enable dwz compression again. This was finally fixed:
  https://sourceware.org/git/?p=dwz.git;a=commit;h=05d55402d9f6
* Wed Nov 24 2021 Tony Jones <tonyj@suse.com>
- Fix build error due to stale conditional around %%files devel
* Wed Nov 24 2021 Jan Engelhardt <jengelh@inai.de>
- Split gtk portion into separate package (pulls in about 40
  packages for graphic systems that are not desired on text
  shells).
- Downgrade Requires: kernel to Recommends:. We are long past
  2.6.31 (its existence is pretty much guaranteed), and it forces
  installation of a distro kernel on systems that compile their own.
* Mon Nov 15 2021 Jiri Slaby <jslaby@suse.cz>
- Cleanup for < 5.14
  * Remove:
    perf-5.14-don-t-install-headers-with-x-permissions.patch
    perf-5.14-remove-shebang-from-scripts-perl-python-.-pl-py.patch
  * -devel is always built
* Wed Nov  3 2021 Jiri Slaby <jslaby@suse.cz>
- Fix for kernel 5.15
  add perf-5.15-don-t-install-headers-with-x-permissions.patch
- skip info files generation which was enabled in 5.15
* Mon Jul 26 2021 Jiri Slaby <jslaby@suse.cz>
- Fix for kernel 5.14
  * add perf-5.14-don-t-install-headers-with-x-permissions.patch
  * add perf-5.14-remove-shebang-from-scripts-perl-python-.-pl-py.patch
* Tue Jun 29 2021 Jiri Slaby <jslaby@suse.cz>
- remove perf-tools-enable-libtraceevent-dynamic-linking.patch
  (it's in 5.13)
* Sat May  8 2021 Tony Jones <tonyj@suse.com>
- Switch to using libtraceevent shared library package.
  New patch: perf-tools-enable-libtraceevent-dynamic-linking.patch
* Mon Apr 26 2021 Jiri Slaby <jslaby@suse.cz>
- remove:
  * 0001-perf-annotate-Fix-jump-parsing-for-C-code.patch
  * 0001-perf-symbols-Resolve-symbols-against-debug-file-firs.patch
  They are part of 5.12 and therefore create a conflict.
* Tue Mar  2 2021 Jiri Slaby <jslaby@suse.cz>
- add:
  * 0001-perf-annotate-Fix-jump-parsing-for-C-code.patch
    (bsc#1182888)
  * 0001-perf-symbols-Resolve-symbols-against-debug-file-firs.patch
    (bsc#1180610)
* Thu Nov 19 2020 Jiri Slaby <jslaby@suse.cz>
- pass GTK2=1 to make (needed after 4751bddd3f98)
* Wed Nov 18 2020 Tony Jones <tonyj@suse.com>
- Resolve build error due to updated kernel-source
  Delete patch: 0001-perf-fix-off-by-ones-in-memset-after-realloc.patch
* Thu Oct  1 2020 Jiri Slaby <jslaby@suse.cz>
- add 0001-perf-fix-off-by-ones-in-memset-after-realloc.patch (bsc#1177113)
* Tue Sep 22 2020 Jiri Slaby <jslaby@suse.com>
- remove perf-cs-etm-move-definition-of-traceid_list-global-variable-from-header-file.patch
  It's a 5.8 patch and we are already at 5.8.
- do not use libexecdir after the latest TW changes
- install bash completion to /usr, not /etc as is now the default
- require libcap, so that we support capabilities
- require babeltrace, so that we support conversion to CTF
- clean up spec file
* Fri Jul 31 2020 Michel Normand <normand@linux.vnet.ibm.com>
- Remove libebl Requires for ppc64/ppc64le (boo#1174714)
  now that elfutils 0.178 do not generate it anymore.
* Wed Jul 22 2020 Mian Yousaf Kaukab <yousaf.kaukab@suse.com>
- Link with CoreSight Trace Decode library (OpenCSD)
* Wed Jul 22 2020 Mian Yousaf Kaukab <yousaf.kaukab@suse.com>
- perf.spec: incorporate automatic changes from osc
* Fri Jun 12 2020 Tony Jones <tonyj@suse.com>
- Fix build breakage on aarch64 and armv7 (bsc#1172741)
  New patch: perf-cs-etm-move-definition-of-traceid_list-global-variable-from-header-file.patch
* Wed Oct 30 2019 Jiri Slaby <jslaby@suse.com>
- perf does not link with LTO, so define _lto_cflags %%{nil}
- add libzstd-devel to BuildRequires to support trace compression
- fix gtk2 detection
* Fri Jun 14 2019 Tony Jones <tonyj@suse.com>
- Update to latest perf
  Delete Python3 support patches now upstream
  Delete patch: update-tests-attr.py-to-support-python3.patch
  Delete patch: remove-shebang-from-scripts-python.patch
  Delete patch: remove-shebang-from-tests-attr.py.patch
  Delete patch: remove-shebang-from-util-setup.py.patch
  Delete patch: add-trace_context-extension-module-to-sys-modules.patch
  Delete patch: use-pybytes-for-attr-in-trace-event-python.patch
  Delete patch: port-event_analyzing_sample-script-to-python3.patch
  Delete patch: port-failed-syscalls-by-pid-script-to-python3.patch
  Delete patch: port-futex-contention-script-to-python3.patch
  Delete patch: port-intel-pt-events-script-to-python3.patch
  Delete patch: port-mem-phys-addr-to-python3.patch
  Delete patch: port-netdev-times-script-to-python3.patch
  Delete patch: port-net_dropmonitor-script-to-python3.patch
  Delete patch: port-powerpc-hcalls-script-to-python3.patch
  Delete patch: port-python-syscall-counts-script-to-python3.patch
  Delete patch: port-sctop-script-to-python3.patch
  Delete patch: port-sql-scripts-to-python3.patch
  Delete patch: port-stackcollapse-script-to-python3.patch
  Delete patch: port-stat-cpi-script-to-python3.patch
  Delete patch: port-syscall-counts-by-pid-script-to-python3.patch
  Delete patch: port-check-perf-trace-script-to-python3.patch
* Wed Jan 16 2019 tiwai@suse.de
- Build with asciidoctor instead of asciidoc (bsc#1075764)
* Fri Jan 11 2019 Tony Jones <tonyj@suse.com>
- Enable python3. Remove all uses of python2 (bsc#1082197)
  New patch: update-tests-attr.py-to-support-python3.patch
  New patch: remove-shebang-from-scripts-python.patch
  New patch: remove-shebang-from-tests-attr.py.patch
  New patch: remove-shebang-from-util-setup.py.patch
  New patch: add-trace_context-extension-module-to-sys-modules.patch
  New patch: use-pybytes-for-attr-in-trace-event-python.patch
  New patch: port-event_analyzing_sample-script-to-python3.patch
  New patch: port-failed-syscalls-by-pid-script-to-python3.patch
  New patch: port-futex-contention-script-to-python3.patch
  New patch: port-intel-pt-events-script-to-python3.patch
  New patch: port-mem-phys-addr-to-python3.patch
  New patch: port-netdev-times-script-to-python3.patch
  New patch: port-net_dropmonitor-script-to-python3.patch
  New patch: port-powerpc-hcalls-script-to-python3.patch
  New patch: port-python-syscall-counts-script-to-python3.patch
  New patch: port-sctop-script-to-python3.patch
  New patch: port-sql-scripts-to-python3.patch
  New patch: port-stackcollapse-script-to-python3.patch
  New patch: port-stat-cpi-script-to-python3.patch
  New patch: port-syscall-counts-by-pid-script-to-python3.patch
  New patch: port-check-perf-trace-script-to-python3.patch
* Wed Dec 12 2018 Tony Jones <tonyj@suse.com>
- Update packaged include files to resolve build failures
* Tue Oct 16 2018 Tony Jones <tonyj@suse.com>
- Update examples paths to resolve build failures.
* Mon Aug 27 2018 tonyj@suse.com
- libebl ppc64 dependancy was inadvertantly dropped, regression from
  "Thu Jun 15 22:27:56 - Add ppc64 requires on libebl (bsc#1040770)".
  Re-add dependancy (bsc#1106048)
* Fri Aug 24 2018 tonyj@suse.com
- Package bpf examples into %%{_docdir}/perf/examples/bpf
* Thu Apr 26 2018 tonyj@suse.com
- Fix build errors
  Drop patch: perf-vendor-events-powerpc-update-power9-events.patch (upstream)
  Drop patch: perf-provide-definition-for-einval-on-32bit.patch (upstream)
* Thu Dec  7 2017 dimstar@opensuse.org
- Escape the usage of %%{VERSION} when calling out to rpm.
  RPM 4.14 has %%{VERSION} defined as 'the main packages version'.
* Mon Dec  4 2017 tonyj@suse.com
- Update power9 events (bsc#1069737)
  New patch: perf-vendor-events-powerpc-update-power9-events.patch
- Update patch context
  Refresh patch: perf-provide-definition-for-einval-on-32bit.patch
* Fri Sep 15 2017 tonyj@suse.com
- Fix x86 32bit build error
  New patch: perf-provide-definition-for-einval-on-32bit.patch
* Thu Sep  1 2016 tonyj@suse.com
- Fix build error (tips.txt) on Leap42.2
- Fix doc file attributes
* Mon Jun  6 2016 jslaby@suse.com
- disable Werror completely. It breaks build due to shadow variables
  in external (perl) headers.
- add %%{?_smp_mflags}
* Mon Apr  4 2016 tonyj@suse.com
- Package perf-tips as docs.
- Include support for xz compressed images
* Mon Jan 11 2016 tonyj@suse.com
- Support strace/data.
* Sun Oct 11 2015 dmueller@suse.com
- enable numa support for aarch64
* Thu Jul 16 2015 antoine.belvire@laposte.net
- Remove perf-fix-branch-stack-mode-cannot-be-set.patch (upstreamed).
* Sun Jun 28 2015 antoine.belvire@laposte.net
- Fix build with GCC 5
  * perf-fix-branch-stack-mode-cannot-be-set.patch
* Wed May 13 2015 tonyj@suse.com
- Fix ppc64/ppc64le breakage due to libexecdir/libdir
* Mon Mar  9 2015 dimstar@opensuse.org
- Inject libdir=%%{_libdir} into make calls.
* Thu Jan  8 2015 dimstar@opensuse.org
- Remove build hack for kernel not building against glibc 2.20.
* Thu Nov 27 2014 dimstar@opensuse.org
- Build hack: if util/util.h does not (yet) define _DEFAULT_SOURCE,
  we export WERROR=0, which removes -Werror from CFLAGS. Once a
  kernel lands that defines _DEFAULT_SOURCE, we fail the build in
  to remove this hack, making it a (hopefully_ short-livinging one.
* Fri Jun 27 2014 tonyj@suse.com
- Build for s390[x] without libunwind (bnc#882855)
* Tue Mar 25 2014 aj@ajaissle.de
- Fix current build including 'trace event' plugins
- Do not include 'trace event' plugins when on armv7l
- BuildRequire libnuma-devel to enable 'perf bench numa mem', but
  only require if we build for ia64 x86_64 ppc64 ppc64le  ppc %%sparc
- Spec cleanup:
  * Add Url: https://perf.wiki.kernel.org/
  * Drop %%clean-section: We don't need to cleanup the buildroot
  * bash_completion.d/perf doesn't need executable bit
* Fri Jan 24 2014 tonyj@suse.com
- Fix build errors (invoke Makefile.perf directly to pass perfexecdir)
- Add /usr/bin/trace alias for perf (mainline b52bc234)
- Add libperf-gtk.so (loaded via dlsym, mainline fc67297b)
* Wed Dec  4 2013 tonyj@suse.com
- Drop patch perl-5.18-nowarn.patch (mainline)
* Thu Sep  5 2013 mls@suse.de
- add libperl_requires, as we link against libperl and thus
  need a specific version of perl
* Wed Aug 21 2013 tonyj@suse.com
- Resolve build errors
- Drop patch perf-tests-ppc64-fix-compile-errors.patch (mainline)
- Refresh patch perl-5.18-nowarn.patch
* Wed Jul 10 2013 tonyj@suse.com
- Add patch 'perf-tests-ppc64-fix-compile-errors.patch' to resolve
  openSUSE:Factory:PowerPC testsuite build errors
* Tue Jul  9 2013 tonyj@suse.com
- Add audit-devel, gtk2-devel and libunwind-devel to support optional
  functionality.
- Add 'perl-5.18-nowarn.patch' to squelch build errors from perl.h
- Add perl_requires
- Fix --version output (copy submakefiles from kernel-source)
- Pass SUSE rpm optflags into make as EXTRA_CFLAGS not CFLAGS
- Stop building with V=1, make output easier to parse
* Tue Dec 25 2012 tonyj@suse.com
- Add /etc/bash_completion.d/perf to %%files (fix build error)
* Wed May 16 2012 toganm@opensuse.org
- Fix build for factory
  * added flex and bison to buildrequires
* Thu May  5 2011 idoenmez@novell.com
- Also copy arch/lib to fix compilation on x86-64
- Correctly depend on libdw-devel to fix dwarf support
- Add newt-devel dependency to enable text user interface
- Re-enable as-needed support since it works now
* Tue Mar  9 2010 tonyj@novell.com
- 2.6.33 changes
  add perf-bench, perf-buildid-list, perf-diff, perf-kmem, perf-probe and
  perf-trace-perl
  [Still pending, update of libdwarf to version > 20081231]
* Thu Nov  5 2009 tonyj@novell.com
- 2.6.32 changes
  add perf-sched, perf-timechart and perf-trace man pages
* Wed Aug 26 2009 aj@suse.de
- Remove libbfd.patch since it does not apply and use
  SUSE_ASNEEDED=0 instead.
- Set flag for asciidoc version 8.
* Sun Aug  2 2009 tonyj@suse.de
- Initial checkin of Performance Counters for Linux (PCL) userspace.
  This builds tools/perf out of kernel-source package and requires
  kernel >= 2.6.31
